"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const table_data_1 = require("@src/table-data");
const utils_1 = require("./support/utils");
const expectedData = [
    { Person: 'Chris', Likes: 'HTML tables', Age: '22' },
    { Person: 'Dennis', Likes: 'Web accessibility', Age: '45' },
    { Person: 'Sarah', Likes: 'JavaScript frameworks', Age: '29' },
    { Person: 'Karen', Likes: 'Web performance', Age: '36' },
];
test('should convert HTML table to data frame with simple table markup', () => __awaiter(void 0, void 0, void 0, function* () {
    // Arrange
    const htmlString = yield (0, utils_1.getHTMLFile)('table.html');
    // Act
    const dataFrame = (0, table_data_1.toDataFrame)(htmlString);
    // Assert
    expect(dataFrame).toEqual(expectedData);
}));
test('should return an empty object from no rows', () => __awaiter(void 0, void 0, void 0, function* () {
    // Arrange
    const htmlString = yield (0, utils_1.getHTMLFile)('table_empty.html');
    // Act
    const dataFrame = (0, table_data_1.toDataFrame)(htmlString);
    // Assert
    expect(dataFrame).toEqual([]);
}));
test('should convert HTML table to data frame with input fields in table markup', () => __awaiter(void 0, void 0, void 0, function* () {
    // Arrange
    const htmlString = yield (0, utils_1.getHTMLFile)('table_input.html');
    // Act
    const dataFrame = (0, table_data_1.toDataFrame)(htmlString, utils_1.defaultHeaders);
    // Assert
    expect(dataFrame).toEqual(expectedData);
}));
test('should convert HTML table using my own headers', () => __awaiter(void 0, void 0, void 0, function* () {
    // Arrange
    const htmlString = yield (0, utils_1.getHTMLFile)('table_1_row.html');
    const expectedWithProvidedKeys = [{ a: 'Chris', '*b': 'HTML tables', c: '22' }];
    // Act
    const dataFrame = (0, table_data_1.toDataFrame)(htmlString, ['a', '*b', 'c']);
    // Assert
    expect(dataFrame).toEqual(expectedWithProvidedKeys);
}));
test('should convert HTML table to data frame with input fields in table markup', () => __awaiter(void 0, void 0, void 0, function* () {
    // Arrange
    const htmlString = yield (0, utils_1.getHTMLFile)('table_textarea.html');
    // Act
    const dataFrame = (0, table_data_1.toDataFrame)(htmlString, utils_1.defaultHeaders);
    // Assert
    expect(dataFrame).toEqual(expectedData);
}));
test('should convert HTML table with Unknown for the missing headers', () => __awaiter(void 0, void 0, void 0, function* () {
    // Arrange
    const htmlString = yield (0, utils_1.getHTMLFile)('table_missing_headers.html');
    const expectedMissingData = [{ Person: 'Chris', Unknown0: 'Record', Likes: 'JavaScript', Age: '22', Unknown1: '' }];
    // Act
    const dataFrame = (0, table_data_1.toDataFrame)(htmlString);
    // Assert
    expect(dataFrame).toEqual(expectedMissingData);
}));
test('should validate inaccurate provided header length', () => __awaiter(void 0, void 0, void 0, function* () {
    // Arrange
    const htmlString = yield (0, utils_1.getHTMLFile)('table_input.html');
    // Act
    try {
        (0, table_data_1.toDataFrame)(htmlString, ['a', 'b']);
    }
    catch (error) {
        // Assert
        expect(error.message).toEqual('The number of provided headers (2) does not match the number of columns in the table (3).');
    }
}));
