"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const table_data_1 = require("@src/table-data");
const table_to_have_1 = require("@src/table-to-have");
const utils_1 = require("./support/utils");
test('should have table row count greater than', () => __awaiter(void 0, void 0, void 0, function* () {
    // Arrange
    const htmlString = yield (0, utils_1.getHTMLFile)('table.html');
    // Act
    const dataFrame = (0, table_data_1.toDataFrame)(htmlString, utils_1.defaultHeaders);
    // Assert
    (0, table_to_have_1.toHaveTableRowCountGreaterThan)(dataFrame, 3);
}));
test('should have column values matching regex', () => __awaiter(void 0, void 0, void 0, function* () {
    // Arrange
    const htmlString = yield (0, utils_1.getHTMLFile)('table.html');
    // Act
    const dataFrame = (0, table_data_1.toDataFrame)(htmlString, utils_1.defaultHeaders);
    // Assert
    (0, table_to_have_1.toHaveColumnValuesToMatchRegex)(dataFrame, 'Age', '\\d{1,2}');
}));
test('should have column values in range', () => __awaiter(void 0, void 0, void 0, function* () {
    // Arrange
    const htmlString = yield (0, utils_1.getHTMLFile)('table.html');
    // Act
    const dataFrame = (0, table_data_1.toDataFrame)(htmlString, utils_1.defaultHeaders);
    // Assert
    (0, table_to_have_1.toHaveColumnValuesToBeInRange)(dataFrame, 'Age', 0, 45);
}));
test('should have column values as numbers', () => __awaiter(void 0, void 0, void 0, function* () {
    // Arrange
    const htmlString = yield (0, utils_1.getHTMLFile)('table.html');
    // Act
    const dataFrame = (0, table_data_1.toDataFrame)(htmlString, utils_1.defaultHeaders);
    // Assert
    (0, table_to_have_1.toHaveColumnValuesToBeNumbers)(dataFrame, 'Age');
}));
test('should have column matching when filtered by', () => __awaiter(void 0, void 0, void 0, function* () {
    // Arrange
    const htmlString = yield (0, utils_1.getHTMLFile)('table.html');
    // Act
    const dataFrame = (0, table_data_1.toDataFrame)(htmlString, utils_1.defaultHeaders);
    // Assert
    (0, table_to_have_1.toHaveColumnToMatchWhenFilteredBy)(dataFrame, 'Age', '22', 'Person', 'Chris');
}));
test('should have column matching group when filtered by', () => __awaiter(void 0, void 0, void 0, function* () {
    // Arrange
    const htmlString = yield (0, utils_1.getHTMLFile)('table.html');
    const group = [
        { filterColumn: 'Person', filterValue: 'Chris' },
        { filterColumn: 'Likes', filterValue: 'HTML tables' },
    ];
    // Act
    const dataFrame = (0, table_data_1.toDataFrame)(htmlString, utils_1.defaultHeaders);
    // Assert
    (0, table_to_have_1.toHaveColumnToMatchGroupWhenFilteredBy)(dataFrame, 'Age', '22', group);
}));
test('should have column not matching', () => __awaiter(void 0, void 0, void 0, function* () {
    // Arrange
    const htmlString = yield (0, utils_1.getHTMLFile)('table.html');
    // Act
    const dataFrame = (0, table_data_1.toDataFrame)(htmlString, utils_1.defaultHeaders);
    // Assert
    (0, table_to_have_1.toHaveColumnToNotMatch)(dataFrame, 'Age', '100');
}));
test('should have table row count', () => __awaiter(void 0, void 0, void 0, function* () {
    // Arrange
    const htmlString = yield (0, utils_1.getHTMLFile)('table.html');
    // Act
    const dataFrame = (0, table_data_1.toDataFrame)(htmlString, utils_1.defaultHeaders);
    // Assert
    (0, table_to_have_1.toHaveTableRowCount)(dataFrame, 4);
}));
test('should have column value', () => __awaiter(void 0, void 0, void 0, function* () {
    // Arrange
    const htmlString = yield (0, utils_1.getHTMLFile)('table_1_row.html');
    // Act
    const dataFrame = (0, table_data_1.toDataFrame)(htmlString, utils_1.defaultHeaders);
    // Assert
    (0, table_to_have_1.toHaveColumnToBeValue)(dataFrame, 'Person', 'Chris');
}));
test('should have column group value', () => __awaiter(void 0, void 0, void 0, function* () {
    // Arrange
    const htmlString = yield (0, utils_1.getHTMLFile)('table_1_row.html');
    const group = [
        { filterColumn: 'Person', filterValue: 'Chris' },
        { filterColumn: 'Likes', filterValue: 'HTML tables' },
    ];
    // Act
    const dataFrame = (0, table_data_1.toDataFrame)(htmlString, utils_1.defaultHeaders);
    // Assert
    (0, table_to_have_1.toHaveColumnGroupToBeValue)(dataFrame, group);
}));
test('should have column group values', () => __awaiter(void 0, void 0, void 0, function* () {
    // Arrange
    const htmlString = yield (0, utils_1.getHTMLFile)('table_2_row.html');
    const groupA = [
        { filterColumn: 'Person', filterValue: 'Chris' },
        { filterColumn: 'Likes', filterValue: 'HTML tables' },
        { filterColumn: 'Age', filterValue: '22' },
    ];
    const groupB = [
        { filterColumn: 'Person', filterValue: 'Dennis' },
        { filterColumn: 'Likes', filterValue: 'Web accessibility' },
        { filterColumn: 'Age', filterValue: '45' },
    ];
    // Act
    const dataFrame = (0, table_data_1.toDataFrame)(htmlString, utils_1.defaultHeaders);
    // Assert
    (0, table_to_have_1.toHaveColumnGroupToBeValues)(dataFrame, [groupA, groupB]);
}));
test('should have table not matching', () => __awaiter(void 0, void 0, void 0, function* () {
    // Arrange
    const htmlString1 = yield (0, utils_1.getHTMLFile)('table_1_row.html');
    const htmlString2 = yield (0, utils_1.getHTMLFile)('table_1b_row.html');
    // Act
    const dataFrame1 = (0, table_data_1.toDataFrame)(htmlString1, utils_1.defaultHeaders);
    const dataFrame2 = (0, table_data_1.toDataFrame)(htmlString2, utils_1.defaultHeaders);
    // Assert
    (0, table_to_have_1.toHaveTableToNotMatch)(dataFrame1, dataFrame2);
}));
test('should have table matching', () => __awaiter(void 0, void 0, void 0, function* () {
    // Arrange
    const htmlString1 = yield (0, utils_1.getHTMLFile)('table_1_row.html');
    const htmlString2 = yield (0, utils_1.getHTMLFile)('table_1_row.html');
    // Act
    const dataFrame1 = (0, table_data_1.toDataFrame)(htmlString1, utils_1.defaultHeaders);
    const dataFrame2 = (0, table_data_1.toDataFrame)(htmlString2, utils_1.defaultHeaders);
    // Assert
    (0, table_to_have_1.toHaveTableToMatch)(dataFrame1, dataFrame2);
}));
